@@ -85,6 +85,9 @@ class RandomForest(
             self.estimator.n_estimators = min(self.estimator.n_estimators,
                                               self.n_estimators)
 
+        if y.ndim == 2 and y.shape[1] == 1:
+            y = y.flatten()
+
         self.estimator.fit(X, y)
         return self
 
