@@ -1,10 +1,16 @@
 import unittest
+import warnings
+
+import pytest
 
 import numpy as np
 import sklearn.metrics
 
 import autosklearn.metrics
 
+from autosklearn.metrics import calculate_score, calculate_loss, calculate_metric
+from autosklearn.constants import BINARY_CLASSIFICATION, REGRESSION
+
 from smac.utils.constants import MAXINT
 
 
@@ -36,7 +42,8 @@ class TestScorer(unittest.TestCase):
         self.assertAlmostEqual(score, 0.5)
 
         scorer = autosklearn.metrics._PredictScorer(
-            'accuracy', sklearn.metrics.accuracy_score, 1, 0, -1, {})
+            name='accuracy', score_func=sklearn.metrics.accuracy_score,
+            optimum=1, worst_possible_result=0, sign=-1, kwargs={})
 
         y_pred = np.array([[1.0, 0.0], [1.0, 0.0], [0.0, 1.0], [0.0, 1.0]])
         score = scorer(y_true, y_pred)
@@ -273,6 +280,11 @@ class TestMetricsDoNotAlterInput(unittest.TestCase):
         for metric, scorer in autosklearn.metrics.REGRESSION_METRICS.items():
             y_true = np.random.random(100).reshape((-1, 1))
             y_pred = y_true.copy() + np.random.randn(100, 1) * 0.1
+
+            if metric == 'mean_squared_log_error':
+                y_true = np.abs(y_true)
+                y_pred = np.abs(y_pred)
+
             y_true_2 = y_true.copy()
             y_pred_2 = y_pred.copy()
             self.assertTrue(np.isfinite(scorer(y_true_2, y_pred_2)))
@@ -319,6 +331,9 @@ class TestMetric(unittest.TestCase):
             current_score = scorer(y_true, y_pred)
             self.assertLess(current_score, previous_score)
 
+            if scorer.name == 'mean_squared_log_error':
+                continue
+
             y_pred = np.array([-1, 0, -1, 0])
             previous_score = current_score
             current_score = scorer(y_true, y_pred)
@@ -367,6 +382,17 @@ class TestMetric(unittest.TestCase):
             self.assertLess(current_score, previous_score)
 
     def test_classification_multiclass(self):
+        # The last check in this test has a mismatch between the number of
+        # labels predicted in y_pred and the number of labels in y_true.
+        # This triggers several warnings but we are aware.
+        #
+        # TODO convert to pytest with fixture
+        #
+        #   This test should be parameterized so we can identify which metrics
+        #   cause which warning specifically and rectify if needed.
+        ignored_warnings = [
+            (UserWarning, 'y_pred contains classes not in y_true')
+        ]
 
         for metric, scorer in autosklearn.metrics.CLASSIFICATION_METRICS.items():
             # Skip functions not applicable for multiclass classification.
@@ -374,31 +400,71 @@ class TestMetric(unittest.TestCase):
                           'precision', 'recall', 'f1', 'precision_samples',
                           'recall_samples', 'f1_samples']:
                 continue
-            y_true = np.array([0.0, 0.0, 1.0, 1.0, 2.0])
-            y_pred = np.array([[1.0, 0.0, 0.0], [1.0, 0.0, 0.0],
-                              [0.0, 1.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]])
+
+            y_true = np.array(
+                [0.0, 0.0, 1.0, 1.0, 2.0]
+            )
+
+            y_pred = np.array([
+                [1.0, 0.0, 0.0],
+                [1.0, 0.0, 0.0],
+                [0.0, 1.0, 0.0],
+                [0.0, 1.0, 0.0],
+                [0.0, 0.0, 1.0]
+            ])
             previous_score = scorer._optimum
             current_score = scorer(y_true, y_pred)
             self.assertAlmostEqual(current_score, previous_score)
 
-            y_pred = np.array([[1.0, 0.0, 0.0], [1.0, 0.0, 0.0],
-                              [1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]])
+            y_pred = np.array([
+                [1.0, 0.0, 0.0],
+                [1.0, 0.0, 0.0],
+                [1.0, 0.0, 0.0],
+                [0.0, 1.0, 0.0],
+                [0.0, 0.0, 1.0],
+            ])
             previous_score = current_score
             current_score = scorer(y_true, y_pred)
             self.assertLess(current_score, previous_score)
 
-            y_pred = np.array([[0.0, 0.0, 1.0], [0.0, 1.0, 0.0],
-                              [1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 1.0, 0.0]])
+            y_pred = np.array([
+                [0.0, 0.0, 1.0],
+                [0.0, 1.0, 0.0],
+                [1.0, 0.0, 0.0],
+                [0.0, 1.0, 0.0],
+                [0.0, 1.0, 0.0]
+            ])
             previous_score = current_score
             current_score = scorer(y_true, y_pred)
             self.assertLess(current_score, previous_score)
 
-            y_pred = np.array([[0.0, 0.0, 1.0], [0.0, 0.0, 1.0],
-                              [1.0, 0.0, 0.0], [1.0, 0.0, 0.0], [0.0, 1.0, 0.0]])
+            y_pred = np.array([
+                [0.0, 0.0, 1.0],
+                [0.0, 0.0, 1.0],
+                [1.0, 0.0, 0.0],
+                [1.0, 0.0, 0.0],
+                [0.0, 1.0, 0.0]
+            ])
             previous_score = current_score
             current_score = scorer(y_true, y_pred)
             self.assertLess(current_score, previous_score)
 
+            # less labels in the targets than in the predictions
+            y_true = np.array([0.0, 0.0, 1.0, 1.0])
+            y_pred = np.array([
+                [1.0, 0.0, 0.0], [1.0, 0.0, 0.0],
+                [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]]
+            )
+
+            with warnings.catch_warnings():
+                for category, message in ignored_warnings:
+                    warnings.filterwarnings(
+                        'ignore', category=category, message=message
+                    )
+
+                score = scorer(y_true, y_pred)
+                self.assertTrue(np.isfinite(score))
+
     def test_classification_multilabel(self):
 
         for metric, scorer in autosklearn.metrics.CLASSIFICATION_METRICS.items():
@@ -426,3 +492,171 @@ class TestMetric(unittest.TestCase):
             previous_score = current_score
             current_score = scorer(y_true, y_pred)
             self.assertLess(current_score, previous_score)
+
+
+class TestCalculateScore(unittest.TestCase):
+
+    def test_unsupported_task_type(self):
+        y_true = np.array([1.0, 1.0, 1.0, 0.0, 0.0, 0.0])
+        y_pred = \
+            np.array([[0.0, 1.0], [0.0, 1.0], [0.0, 1.0], [1.0, 0.0], [1.0, 0.0], [1.0, 0.0]])
+        scorer = autosklearn.metrics.accuracy
+
+        raised = False
+        try:
+            calculate_score(y_true, y_pred, 6, scorer)
+        except NotImplementedError:
+            raised = True
+        self.assertTrue(raised)
+
+    def test_classification_scoring_functions(self):
+
+        scoring_functions = list(autosklearn.metrics.CLASSIFICATION_METRICS.values())
+        scoring_functions.remove(autosklearn.metrics.accuracy)
+        fail_metrics = ['precision_samples', 'recall_samples', 'f1_samples']
+        success_metrics = list(autosklearn.metrics.CLASSIFICATION_METRICS.keys())
+        for metric in fail_metrics:
+            success_metrics.remove(metric)
+
+        y_true = np.array([1.0, 1.0, 1.0, 0.0, 0.0, 0.0])
+        y_pred = \
+            np.array([[0.0, 1.0], [0.0, 1.0], [0.0, 1.0], [1.0, 0.0], [1.0, 0.0], [1.0, 0.0]])
+        score_dict = calculate_score(y_true, y_pred, BINARY_CLASSIFICATION,
+                                     autosklearn.metrics.accuracy,
+                                     scoring_functions)
+
+        self.assertIsInstance(score_dict, dict)
+        self.assertTrue(len(success_metrics), len(score_dict))
+        for metric in fail_metrics:
+            self.assertNotIn(metric, score_dict.keys())
+        for metric in success_metrics:
+            self.assertIn(metric, score_dict.keys())
+            self.assertAlmostEqual(autosklearn.metrics.CLASSIFICATION_METRICS[metric]._optimum,
+                                   score_dict[metric])
+
+    def test_regression_scoring_functions(self):
+
+        scoring_functions = list(autosklearn.metrics.REGRESSION_METRICS.values())
+        scoring_functions.remove(autosklearn.metrics.root_mean_squared_error)
+
+        metrics = list(autosklearn.metrics.REGRESSION_METRICS.keys())
+        metrics.remove('mean_squared_log_error')
+
+        y_true = np.array([1, 2, 3, -4])
+        y_pred = y_true.copy()
+
+        score_dict = calculate_score(y_true, y_pred, REGRESSION,
+                                     autosklearn.metrics.root_mean_squared_error,
+                                     scoring_functions)
+
+        self.assertIsInstance(score_dict, dict)
+        self.assertTrue(len(metrics), len(score_dict))
+        for metric in metrics:
+            self.assertIn(metric, score_dict.keys())
+            self.assertAlmostEqual(autosklearn.metrics.REGRESSION_METRICS[metric]._optimum,
+                                   score_dict[metric])
+
+    def test_classification_only_metric(self):
+        y_true = np.array([1.0, 1.0, 1.0, 0.0, 0.0, 0.0])
+        y_pred = \
+            np.array([[0.0, 1.0], [0.0, 1.0], [0.0, 1.0], [1.0, 0.0], [1.0, 0.0], [1.0, 0.0]])
+        scorer = autosklearn.metrics.accuracy
+
+        score = calculate_score(y_true, y_pred, BINARY_CLASSIFICATION, scorer)
+
+        previous_score = scorer._optimum
+        self.assertAlmostEqual(score, previous_score)
+
+    def test_regression_only_metric(self):
+        y_true = np.array([1, 2, 3, 4])
+        y_pred = y_true.copy()
+        scorer = autosklearn.metrics.root_mean_squared_error
+
+        score = calculate_score(y_true, y_pred, REGRESSION, scorer)
+        previous_score = scorer._optimum
+        self.assertAlmostEqual(score, previous_score)
+
+
+def test_calculate_loss():
+    # In a 0-1 ranged scorer, make sure that the loss
+    # has an expected positive value
+    y_pred = np.array([0, 1, 0, 1, 1, 1, 0, 0, 0, 0])
+    y_true = np.array([0, 1, 0, 1, 1, 0, 0, 0, 0, 0])
+    score = sklearn.metrics.accuracy_score(y_true, y_pred)
+    assert pytest.approx(score) == calculate_score(
+        solution=y_true,
+        prediction=y_pred,
+        task_type=BINARY_CLASSIFICATION,
+        metric=autosklearn.metrics.accuracy,
+    )
+    assert pytest.approx(1.0 - score) == calculate_loss(
+        solution=y_true,
+        prediction=y_pred,
+        task_type=BINARY_CLASSIFICATION,
+        metric=autosklearn.metrics.accuracy,
+    )
+
+    # Test the dictionary case
+    score_dict = calculate_score(
+        solution=y_true,
+        prediction=y_pred,
+        task_type=BINARY_CLASSIFICATION,
+        metric=autosklearn.metrics.accuracy,
+        scoring_functions=[autosklearn.metrics.accuracy, autosklearn.metrics.balanced_accuracy]
+    )
+    expected_score_dict = {
+        'accuracy': 0.9,
+        'balanced_accuracy': 0.9285714285714286,
+    }
+    loss_dict = calculate_loss(
+        solution=y_true,
+        prediction=y_pred,
+        task_type=BINARY_CLASSIFICATION,
+        metric=autosklearn.metrics.accuracy,
+        scoring_functions=[autosklearn.metrics.accuracy, autosklearn.metrics.balanced_accuracy]
+    )
+    for expected_metric, expected_score in expected_score_dict.items():
+        assert pytest.approx(expected_score) == score_dict[expected_metric]
+        assert pytest.approx(1-expected_score) == loss_dict[expected_metric]
+
+    # Lastly make sure that metrics whose optimum is zero
+    # are also properly working
+    y_true = np.array([0.1, 0.2, 0.3, 0.4, 0.5, 0.6])
+    y_pred = np.array([0.11, 0.22, 0.33, 0.44, 0.55, 0.66])
+    score = sklearn.metrics.mean_squared_error(y_true, y_pred)
+    assert pytest.approx(0 - score) == calculate_score(
+        solution=y_true,
+        prediction=y_pred,
+        task_type=REGRESSION,
+        metric=autosklearn.metrics.mean_squared_error,
+    )
+    assert pytest.approx(score) == calculate_loss(
+        solution=y_true,
+        prediction=y_pred,
+        task_type=REGRESSION,
+        metric=autosklearn.metrics.mean_squared_error,
+    )
+
+
+def test_calculate_metric():
+    # metric to be maximized
+    y_pred = np.array([0, 1, 0, 1, 1, 1, 0, 0, 0, 0])
+    y_true = np.array([0, 1, 0, 1, 1, 0, 0, 0, 0, 0])
+    score = sklearn.metrics.accuracy_score(y_true, y_pred)
+    assert pytest.approx(score) == calculate_metric(
+        solution=y_true,
+        prediction=y_pred,
+        task_type=BINARY_CLASSIFICATION,
+        metric=autosklearn.metrics.accuracy,
+    )
+
+    # metric to be minimized
+    y_true = np.array([0.1, 0.2, 0.3, 0.4, 0.5, 0.6])
+    y_pred = np.array([0.11, 0.22, 0.33, 0.44, 0.55, 0.66])
+    score = sklearn.metrics.mean_squared_error(y_true, y_pred)
+    assert pytest.approx(score) == calculate_metric(
+        solution=y_true,
+        prediction=y_pred,
+        task_type=REGRESSION,
+        metric=autosklearn.metrics.mean_squared_error,
+    )
