@@ -11,18 +11,19 @@ class PassiveAggressiveComponentTest(BaseClassificationComponentTest):
     __test__ = True
 
     res = dict()
-    res["default_iris"] = 0.92
-    res["iris_n_calls"] = 5
-    res["default_iris_iterative"] = 1.0
-    res["default_iris_proba"] = 0.29271032477461295
-    res["default_iris_sparse"] = 0.4
-    res["default_digits"] = 0.9156041287188829
+    res["default_iris"] = 0.98
+    res["iris_n_calls"] = 6
+    res["default_iris_iterative"] = res['default_iris']
+    res["iris_iterative_n_iter"] = 64
+    res["default_iris_proba"] = 0.27840521921952033
+    res["default_iris_sparse"] = 0.48
+    res["default_digits"] = 0.9162112932604736
     res["digits_n_calls"] = 6
-    res["default_digits_iterative"] = 0.9174256223436551
-    res["default_digits_binary"] = 0.9927140255009107
-    res["default_digits_multilabel"] = 0.90997912489192
+    res["default_digits_iterative"] = res['default_digits']
+    res["digits_iterative_n_iter"] = 64
+    res["default_digits_binary"] = 0.99210686095932
+    res["default_digits_multilabel"] = 0.910908768565592
     res["default_digits_multilabel_proba"] = 1.0
-    res['ignore_hps'] = ['max_iter']
 
     sk_mod = sklearn.linear_model.PassiveAggressiveClassifier
     module = PassiveAggressive
