@@ -10,16 +10,16 @@ class ExtraTreesComponentTest(BaseRegressionComponentTest):
     __test__ = True
 
     res = dict()
-    res["default_boston"] = 0.8552491508927406
+    res["default_boston"] = 0.8539264243687228
     res["boston_n_calls"] = 9
-    res["default_boston_iterative"] = 0.8539080454228811
-    res["default_boston_sparse"] = 0.4177781339904245
-    res["default_boston_iterative_sparse"] = 0.4188803940560917
-    res["default_diabetes"] = 0.39073511653135706
+    res["default_boston_iterative"] = res['default_boston']
+    res["default_boston_sparse"] = 0.411211701806908
+    res["default_boston_iterative_sparse"] = res['default_boston_sparse']
+    res["default_diabetes"] = 0.3885150255877827
     res["diabetes_n_calls"] = 9
-    res["default_diabetes_iterative"] = 0.3900924379086915
-    res["default_diabetes_sparse"] = 0.24547114408164694
-    res["default_diabetes_iterative_sparse"] = 0.25129575820882655
+    res["default_diabetes_iterative"] = res['default_diabetes']
+    res["default_diabetes_sparse"] = 0.2422804139169642
+    res["default_diabetes_iterative_sparse"] = res['default_diabetes_sparse']
 
     sk_mod = sklearn.ensemble.ExtraTreesRegressor
     module = ExtraTreesRegressor
