@@ -9,16 +9,16 @@ class RandomForestComponentTest(BaseRegressionComponentTest):
     __test__ = True
 
     res = dict()
-    res["default_boston"] = 0.8418942156964226
+    res["default_boston"] = 0.8410063895401654
     res["boston_n_calls"] = 9
-    res["default_boston_iterative"] = 0.8413252775463473
-    res["default_boston_sparse"] = 0.4262240490232485
-    res["default_boston_iterative_sparse"] = 0.42575416243818553
-    res["default_diabetes"] = 0.3438707361168547
+    res["default_boston_iterative"] = res['default_boston']
+    res["default_boston_sparse"] = 0.4194462097407078
+    res["default_boston_iterative_sparse"] = res['default_boston_sparse']
+    res["default_diabetes"] = 0.3496051170409269
     res["diabetes_n_calls"] = 9
-    res["default_diabetes_iterative"] = 0.3410928574942581
-    res["default_diabetes_sparse"] = 0.24330715569007455
-    res["default_diabetes_iterative_sparse"] = 0.24158474583742073
+    res["default_diabetes_iterative"] = res['default_diabetes']
+    res["default_diabetes_sparse"] = 0.2383300978781976
+    res["default_diabetes_iterative_sparse"] = res['default_diabetes_sparse']
 
     sk_mod = sklearn.ensemble.RandomForestRegressor
     module = RandomForest
