@@ -1,16 +1,18 @@
 import copy
+import itertools
 import resource
-import sys
-import traceback
+import tempfile
 import unittest
 import unittest.mock
 
+from joblib import Memory
 import numpy as np
 import sklearn.datasets
 import sklearn.decomposition
 from sklearn.base import clone
 import sklearn.ensemble
 import sklearn.svm
+from sklearn.utils.validation import check_is_fitted
 
 from ConfigSpace.configuration_space import ConfigurationSpace
 from ConfigSpace.hyperparameters import CategoricalHyperparameter
@@ -19,10 +21,13 @@ from autosklearn.pipeline.regression import SimpleRegressionPipeline
 from autosklearn.pipeline.components.base import \
     AutoSklearnPreprocessingAlgorithm, AutoSklearnRegressionAlgorithm
 import autosklearn.pipeline.components.regression as regression_components
+from autosklearn.pipeline.components.base import AutoSklearnComponent, AutoSklearnChoice
 import autosklearn.pipeline.components.feature_preprocessing as preprocessing_components
 from autosklearn.pipeline.util import get_dataset
 from autosklearn.pipeline.constants import SPARSE, DENSE, SIGNED_DATA, UNSIGNED_DATA, PREDICTIONS
 
+from test.test_pipeline.ignored_warnings import regressor_warnings, ignore_warnings
+
 
 class SimpleRegressionPipelineTest(unittest.TestCase):
     _multiprocess_can_split_ = True
@@ -48,6 +53,7 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
             self.assertIn('handles_classification', props)
             self.assertIn('handles_multiclass', props)
             self.assertIn('handles_multilabel', props)
+            self.assertIn('handles_multioutput', props)
             self.assertFalse(props['handles_classification'])
             self.assertFalse(props['handles_multiclass'])
             self.assertFalse(props['handles_multilabel'])
@@ -90,6 +96,38 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
         self._test_configurations(cs, make_sparse=True,
                                   dataset_properties=dataset_properties)
 
+    def test_multioutput(self):
+        cache = Memory(location=tempfile.gettempdir())
+        cached_func = cache.cache(
+            sklearn.datasets.make_regression
+        )
+        X, Y = cached_func(
+            n_samples=250,
+            n_features=20,
+            n_informative=9,
+            n_targets=4,
+            bias=0.5,
+            effective_rank=10,
+            tail_strength=0.4,
+            noise=0.3,
+            shuffle=True,
+            coef=False,
+            random_state=1
+        )
+        X_train = X[:200, :]
+        Y_train = Y[:200, :]
+        X_test = X[200:, :]
+        Y_test = Y[200:, :]
+
+        data = {'X_train': X_train, 'Y_train': Y_train,
+                'X_test': X_test, 'Y_test': Y_test}
+
+        dataset_properties = {'multioutput': True}
+        pipeline = SimpleRegressionPipeline(dataset_properties=dataset_properties)
+        cs = pipeline.get_hyperparameter_search_space()
+
+        self._test_configurations(cs, data=data, dataset_properties=dataset_properties)
+
     def _test_configurations(self, configurations_space, make_sparse=False,
                              data=None, dataset_properties=None):
         # Use a limit of ~4GiB
@@ -128,14 +166,39 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
                 X_test = data['X_test'].copy()
                 data['Y_test'].copy()
 
-            cls = SimpleRegressionPipeline(random_state=1,
-                                           dataset_properties=dataset_properties)
+            cls = SimpleRegressionPipeline(
+                random_state=1,
+                dataset_properties=dataset_properties
+            )
             cls.set_hyperparameters(config)
+
+            # First make sure that for this configuration, setting the parameters
+            # does not mistakenly set the estimator as fitted
+            for name, step in cls.named_steps.items():
+                with self.assertRaisesRegex(sklearn.exceptions.NotFittedError,
+                                            "instance is not fitted yet"):
+                    check_is_fitted(step)
+
             try:
-                cls.fit(X_train, Y_train)
+                with ignore_warnings(regressor_warnings):
+                    cls.fit(X_train, Y_train)
+
+                # After fit, all components should be tagged as fitted
+                # by sklearn. Check is fitted raises an exception if that
+                # is not the case
+                try:
+                    for name, step in cls.named_steps.items():
+                        check_is_fitted(step)
+                except sklearn.exceptions.NotFittedError:
+                    self.fail("config={} raised NotFittedError unexpectedly!".format(
+                        config
+                    ))
+
                 cls.predict(X_test)
             except MemoryError:
                 continue
+            except np.linalg.LinAlgError:
+                continue
             except ValueError as e:
                 if "Floating-point under-/overflow occurred at epoch" in \
                         e.args[0]:
@@ -151,10 +214,13 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
                 elif 'The condensed distance matrix must contain only finite ' \
                      'values.' in e.args[0]:
                     continue
+                elif "zero-size array to reduction operation maximum which has no " \
+                     "identity" in e.args[0]:
+                    continue
                 else:
-                    print(config)
-                    print(traceback.format_exc())
+                    e.args += (f"config={config}",)
                     raise e
+
             except RuntimeWarning as e:
                 if "invalid value encountered in sqrt" in e.args[0]:
                     continue
@@ -167,28 +233,27 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
                 elif "invalid value encountered in multiply" in e.args[0]:
                     continue
                 else:
-                    print(config)
-                    traceback.print_tb(sys.exc_info()[2])
+                    e.args += (f"config={config}",)
                     raise e
+
             except UserWarning as e:
                 if "FastICA did not converge" in e.args[0]:
                     continue
                 else:
-                    print(config)
-                    traceback.print_tb(sys.exc_info()[2])
+                    e.args += (f"config={config}",)
                     raise e
+
             except Exception as e:
                 if "Multiple input features cannot have the same target value" in e.args[0]:
                     continue
                 else:
-                    print(config)
-                    traceback.print_tb(sys.exc_info()[2])
+                    e.args += (f"config={config}",)
                     raise e
 
     def test_default_configuration(self):
         for i in range(2):
             X_train, Y_train, X_test, Y_test = get_dataset(dataset='diabetes')
-            auto = SimpleRegressionPipeline()
+            auto = SimpleRegressionPipeline(random_state=1)
             auto = auto.fit(X_train, Y_train)
             predictions = auto.predict(copy.deepcopy(X_test))
             # The lower the worse
@@ -199,8 +264,12 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
 
     def test_default_configuration_iterative_fit(self):
         regressor = SimpleRegressionPipeline(
-            include={'regressor': ['random_forest'],
-                     'feature_preprocessor': ['no_preprocessing']})
+            random_state=1,
+            include={
+                'regressor': ['random_forest'],
+                'feature_preprocessor': ['no_preprocessing']
+            }
+        )
         X_train, Y_train, X_test, Y_test = get_dataset(dataset='boston')
         regressor.fit_transformer(X_train, Y_train)
         for i in range(1, 11):
@@ -218,46 +287,59 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
         self.assertIsInstance(cs, ConfigurationSpace)
         conditions = cs.get_conditions()
         hyperparameters = cs.get_hyperparameters()
-        self.assertEqual(140, len(hyperparameters))
-        self.assertEqual(len(hyperparameters) - 6, len(conditions))
+        forbiddens = cs.get_forbiddens()
+        self.assertEqual(156, len(hyperparameters))
+        self.assertEqual(len(hyperparameters) - 3, len(conditions))
+        self.assertEqual(len(forbiddens), 35)
 
     def test_get_hyperparameter_search_space_include_exclude_models(self):
-        cs = SimpleRegressionPipeline(
-            include={'regressor': ['random_forest']}).get_hyperparameter_search_space()
+        regressor = SimpleRegressionPipeline(
+            include={'regressor': ['random_forest']}
+        )
+        cs = regressor.get_hyperparameter_search_space()
         self.assertEqual(
             cs.get_hyperparameter('regressor:__choice__'),
             CategoricalHyperparameter('regressor:__choice__', ['random_forest']),
-            )
+        )
 
         # TODO add this test when more than one regressor is present
-        cs = SimpleRegressionPipeline(exclude={'regressor': ['random_forest']}).\
-            get_hyperparameter_search_space()
+        regressor = SimpleRegressionPipeline(
+            exclude={'regressor': ['random_forest']}
+        )
+        cs = regressor.get_hyperparameter_search_space()
         self.assertNotIn('random_forest', str(cs))
 
-        cs = SimpleRegressionPipeline(include={'feature_preprocessor': ['pca']}).\
-            get_hyperparameter_search_space()
+        regressor = SimpleRegressionPipeline(
+            include={'feature_preprocessor': ['pca']}
+        )
+        cs = regressor.get_hyperparameter_search_space()
         self.assertEqual(cs.get_hyperparameter(
             'feature_preprocessor:__choice__'),
             CategoricalHyperparameter('feature_preprocessor:__choice__', ['pca']))
 
-        cs = SimpleRegressionPipeline(
-            exclude={'feature_preprocessor': ['no_preprocessing']}).\
-            get_hyperparameter_search_space()
+        regressor = SimpleRegressionPipeline(
+            exclude={'feature_preprocessor': ['no_preprocessing']}
+        )
+        cs = regressor.get_hyperparameter_search_space()
         self.assertNotIn('no_preprocessing', str(cs))
 
     def test_get_hyperparameter_search_space_preprocessor_contradicts_default_classifier(
-            self):
-        cs = SimpleRegressionPipeline(include={'feature_preprocessor': ['densifier']},
-                                      dataset_properties={'sparse': True}).\
-            get_hyperparameter_search_space()
+        self
+    ):
+        regressor = SimpleRegressionPipeline(
+            include={'feature_preprocessor': ['densifier']},
+            dataset_properties={'sparse': True}
+        )
+        cs = regressor.get_hyperparameter_search_space()
         self.assertEqual(
             cs.get_hyperparameter('regressor:__choice__').default_value,
             'gradient_boosting'
         )
 
-        cs = SimpleRegressionPipeline(
-            include={'feature_preprocessor': ['nystroem_sampler']}).\
-            get_hyperparameter_search_space()
+        regressor = SimpleRegressionPipeline(
+            include={'feature_preprocessor': ['nystroem_sampler']}
+        )
+        cs = regressor.get_hyperparameter_search_space()
         self.assertEqual(
             cs.get_hyperparameter('regressor:__choice__').default_value,
             'sgd'
@@ -281,7 +363,7 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
             "Cannot find a legal default configuration",
             SimpleRegressionPipeline,
             include={
-                'regressor': ['ridge_regression'],
+                'regressor': ['extra_trees'],
                 'feature_preprocessor': ['densifier']
             },
             dataset_properties={'sparse': True}
@@ -324,7 +406,11 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
         include = {'regressor': ['decision_tree']}
         cs = SimpleRegressionPipeline(include=include).get_hyperparameter_search_space()
         default = cs.get_default_configuration()
-        regressor = SimpleRegressionPipeline(default, include=include)
+        regressor = SimpleRegressionPipeline(
+            config=default,
+            random_state=1,
+            include=include
+        )
 
         X_train, Y_train, X_test, Y_test = get_dataset(dataset='boston')
         regressor.fit(X_train, Y_train)
@@ -340,12 +426,19 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
     def test_predict_batched_sparse(self):
         dataset_properties = {'sparse': True}
         include = {'regressor': ['decision_tree']}
-        cs = SimpleRegressionPipeline(dataset_properties=dataset_properties,
-                                      include=include).get_hyperparameter_search_space()
+
+        cs = SimpleRegressionPipeline(
+            dataset_properties=dataset_properties,
+            include=include
+        ).get_hyperparameter_search_space()
+
         default = cs.get_default_configuration()
-        regressor = SimpleRegressionPipeline(default,
-                                             dataset_properties=dataset_properties,
-                                             include=include)
+        regressor = SimpleRegressionPipeline(
+            config=default,
+            random_state=1,
+            dataset_properties=dataset_properties,
+            include=include
+        )
 
         X_train, Y_train, X_test, Y_test = get_dataset(dataset='boston',
                                                        make_sparse=True)
@@ -373,7 +466,7 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
 
     def test_pipeline_clonability(self):
         X_train, Y_train, X_test, Y_test = get_dataset(dataset='boston')
-        auto = SimpleRegressionPipeline()
+        auto = SimpleRegressionPipeline(random_state=1)
         auto = auto.fit(X_train, Y_train)
         auto_clone = clone(auto)
         auto_clone_params = auto_clone.get_params()
@@ -400,3 +493,160 @@ class SimpleRegressionPipelineTest(unittest.TestCase):
 
     def test_get_params(self):
         pass
+
+    def _test_set_hyperparameter_choice(self, expected_key, implementation, config_dict):
+        """
+        Given a configuration in config, this procedure makes sure that
+        the given implementation, which should be a Choice component, honors
+        the type of the object, and any hyperparameter associated to it
+        """
+        keys_checked = [expected_key]
+        implementation_type = config_dict[expected_key]
+        expected_type = implementation.get_components()[implementation_type]
+        self.assertIsInstance(implementation.choice, expected_type)
+
+        # Are there further hyperparams?
+        # A choice component might have attribute requirements that we need to check
+        expected_sub_key = expected_key.replace(':__choice__', ':') + implementation_type
+        expected_attributes = {}
+        if 'data_preprocessor:__choice__' in expected_key:
+            # We have to check both the numerical and categorical
+            to_check = {
+                'numerical_transformer': implementation.choice.numer_ppl.named_steps,
+                'categorical_transformer': implementation.choice.categ_ppl.named_steps,
+            }
+
+            for data_type, pipeline in to_check.items():
+                for sub_name, sub_step in pipeline.items():
+                    # If it is a Choice, make sure it is the correct one!
+                    if isinstance(sub_step, AutoSklearnChoice):
+                        key = "data_preprocessor:feature_type:{}:{}:__choice__".format(
+                            data_type,
+                            sub_name
+                        )
+                        keys_checked.extend(
+                            self._test_set_hyperparameter_choice(
+                                key, sub_step, config_dict
+                            )
+                        )
+                    # If it is a component, make sure it has the correct hyperparams
+                    elif isinstance(sub_step, AutoSklearnComponent):
+                        keys_checked.extend(
+                            self._test_set_hyperparameter_component(
+                                "data_preprocessor:feature_type:{}:{}".format(
+                                    data_type,
+                                    sub_name
+                                ),
+                                sub_step, config_dict
+                            )
+                        )
+                    else:
+                        raise ValueError("New type of pipeline component!")
+            return keys_checked
+        else:
+            for key, value in config_dict.items():
+                if key != expected_key and expected_sub_key in key:
+                    expected_attributes[key.split(':')[-1]] = value
+                    keys_checked.append(key)
+        if expected_attributes:
+            attributes = vars(implementation.choice)
+            # Cannot check the whole dictionary, just names, as some
+            # classes map the text hyperparameter directly to a function!
+            for expected_attribute in expected_attributes.keys():
+                self.assertIn(expected_attribute, attributes.keys())
+        return keys_checked
+
+    def _test_set_hyperparameter_component(self, expected_key, implementation, config_dict):
+        """
+        Given a configuration in config, this procedure makes sure that
+        the given implementation, which should be a autosklearn component, honors
+        is created with the desired hyperparameters stated in config_dict
+        """
+        keys_checked = []
+        attributes = vars(implementation)
+        expected_attributes = {}
+        for key, value in config_dict.items():
+            if expected_key in key:
+                keys_checked.append(key)
+                key = key.replace(expected_key + ':', '')
+                if ':' in key:
+                    raise ValueError("This utility should only be called with a "
+                                     "matching string that produces leaf configurations, "
+                                     "that is no further colons are expected, yet key={}"
+                                     "".format(
+                                            key
+                                        )
+                                     )
+                expected_attributes[key] = value
+        # Cannot check the whole dictionary, just names, as some
+        # classes map the text hyperparameter directly to a function!
+        for expected_attribute in expected_attributes.keys():
+            self.assertIn(expected_attribute, attributes.keys())
+        return keys_checked
+
+    def test_set_hyperparameters_honors_configuration(self):
+        """Makes sure that a given configuration is honored in practice.
+
+        This method tests that the set hyperparameters actually create objects
+        that comply with the given configuration. It iterates trough the pipeline to
+        make sure we did not miss a step, but also checks at the end that every
+        configuration from Config was checked
+
+        Also considers random_state and ensures pipeline steps correctly recieve
+        the right random_state
+        """
+
+        all_combinations = list(itertools.product([True, False], repeat=4))
+        for sparse, multilabel, signed, multiclass, in all_combinations:
+            dataset_properties = {
+                'sparse': sparse,
+                'multilabel': multilabel,
+                'multiclass': multiclass,
+                'signed': signed,
+            }
+            random_state = 1
+            auto = SimpleRegressionPipeline(
+                random_state=random_state,
+                dataset_properties=dataset_properties,
+            )
+            cs = auto.get_hyperparameter_search_space()
+            config = cs.sample_configuration()
+
+            # Set hyperparameters takes a given config and translate
+            # a config to an actual implementation
+            auto.set_hyperparameters(config)
+            config_dict = config.get_dictionary()
+
+            # keys to check is our mechanism to ensure that every
+            # every config key is checked
+            keys_checked = []
+
+            for name, step in auto.named_steps.items():
+                if name == 'data_preprocessor':
+                    keys_checked.extend(
+                        self._test_set_hyperparameter_choice(
+                            'data_preprocessor:__choice__', step, config_dict
+                        )
+                    )
+                    self.assertEqual(step.random_state, random_state)
+                elif name == 'feature_preprocessor':
+                    keys_checked.extend(
+                        self._test_set_hyperparameter_choice(
+                            'feature_preprocessor:__choice__', step, config_dict
+                        )
+                    )
+                    self.assertEqual(step.random_state, random_state)
+                elif name == 'regressor':
+                    keys_checked.extend(
+                        self._test_set_hyperparameter_choice(
+                            'regressor:__choice__', step, config_dict
+                        )
+                    )
+                    self.assertEqual(step.random_state, random_state)
+                else:
+                    raise ValueError("Found another type of step! Need to update this check"
+                                     " {}. ".format(name)
+                                     )
+
+            # Make sure we checked the whole configuration
+            self.assertSetEqual(set(config_dict.keys()), set(keys_checked))
